@@ -1,7 +1,4 @@
 # -*- coding: utf-8 -
-#
-# This file is part of restkit released under the MIT license.
-# See the NOTICE for more information.
 from webob import exc
 from webob.compat import PY3, url_quote
 import logging
@@ -86,9 +83,13 @@ class HttpClient(object):
         response = conn.getresponse()
         status = '%s %s' % (response.status, response.reason)
         length = response.getheader('content-length')
+        resp_headers = [
+            (k, v) for (k, v) in response.getheaders()
+            if k.lower() != 'transfer-encoding'
+        ]
         body = response.read(int(length)) if length else response.read()
         result = (status, response.getheader('location', None),
-                  response.getheaders(), [body])
+                  resp_headers, [body])
         conn.close()
         return result
 
